==> haskell-configfile-1.1.4-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-DtxjaZQBKSi97iNuSNeCZe
key: ConfigFile-1.1.4-DtxjaZQBKSi97iNuSNeCZe
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: f25af196463132f37f21e7bacbd344f5
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.4.2/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-DtxjaZQBKSi97iNuSNeCZe
depends:
    MissingH-1.4.0.1-v3UugSMRLHJkMPTsAzZR4 base-4.11.1.0
    containers-0.5.11.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: MissingH-1.4.0.1-v3UugSMRLHJkMPTsAzZR4=284a9af5f81a159df2333047ccb326ed
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             mtl-2.2.2=a7bec7c72de63625528e8aa4479db2c8
             parsec-3.1.13.0=b976f306e11b572c7d5898bcff511199
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-sRnyQZW1fH6HlG7ty4Uir
key: ConfigFile-1.1.4-sRnyQZW1fH6HlG7ty4Uir
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: 85d204d59aeec466c58dddf466cf6f95
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-sRnyQZW1fH6HlG7ty4Uir
depends:
    MissingH-1.4.0.1-8yY8ibppwosKONNacw6tE2 base-4.11.1.0
    containers-0.5.11.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: MissingH-1.4.0.1-8yY8ibppwosKONNacw6tE2=a9eaa2b3d580d66be495a24b8cc9e6cf
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
